🌷️ Thank you for your interest in supporting Cython! 🌷️
======================================================

Managing, maintaining and advancing a project as large as Cython takes
**a lot of time and dedication**.  This is really a full-time job that
is currently done by **Stefan Behnel**, paid by users just like you.

**Your support can make a difference**
for improving a great tool that helps you every day!

Please consider signing a subscription for continuous project support via

* `GitHub Sponsors <https://github.com/users/scoder/sponsorship>`_
* `Tidelift <https://tidelift.com/subscription/pkg/pypi-cython>`_
* `PayPal <https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=HLS9JEYD4ETB6&source=url>`_

or donating via

* `PayPal <https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=HLS9JEYD4ETB6&source=url>`_
